@@ -1,17 +1,10 @@
 from typing import Optional, Union
 
-from grpc.aio import Metadata
-
 from .. import errors
 
-
 DEFAULT_STRING_CONVERSION_ERROR = "Could not decode bytes to UTF-8"
 
 
-def _make_metadata(cache_name: str) -> Metadata:
-    return Metadata(("cache", cache_name))  # type: ignore[misc]
-
-
 def _validate_cache_name(cache_name: str) -> None:
     if cache_name is None or not isinstance(cache_name, str):
         raise errors.InvalidArgumentError("Cache name must be a non-empty string")
