@@ -1,9 +1,10 @@
 import json
 from datetime import datetime
 from enum import Enum
-from typing import Any, Optional, List, Mapping
+from typing import Any, List, Optional
 
 from momento_wire_types import cacheclient_pb2 as cache_client_types
+
 from . import _cache_service_errors_converter as error_converter
 from . import logs
 
@@ -47,33 +48,15 @@ class CacheSetResponse:
         return f"CacheSetResponse(key={self._key!r}, value={self._value!r})"
 
 
-class CacheSetMultiResponse:
-    def __init__(self, items: Mapping[bytes, bytes]):
-        self._items = items
-
-    def items(self) -> Mapping[str, str]:
-        return {
-            key.decode("utf-8"): value.decode("utf-8")
-            for key, value in self._items.items()
-        }
-
-    def items_as_bytes(self) -> Mapping[bytes, bytes]:
-        return self._items
-
-    def __str__(self) -> str:
-        return self.__repr__()
-
-    def __repr__(self) -> str:
-        return f"CacheSetMultiResponse(items={self._items!r})"
-
-
 class CacheGetResponse:
     def __init__(self, value: bytes, status: CacheGetStatus):
         self._value = value
         self._status = status
 
     @staticmethod
-    def from_grpc_response(grpc_get_response: Any) -> "CacheGetResponse":  # type: ignore[misc]
+    def from_grpc_response(  # type: ignore[misc]
+        grpc_get_response: cache_client_types._GetResponse,
+    ) -> "CacheGetResponse":
         """Initializes CacheGetResponse to handle gRPC get response.
 
         Args:
@@ -89,9 +72,7 @@ class CacheGetResponse:
         elif grpc_get_response.result == cache_client_types.Miss:  # type: ignore[misc]
             status = CacheGetStatus.MISS
         else:
-            logs.debug(
-                "Get received unsupported ECacheResult: %s", grpc_get_response.result  # type: ignore[misc]
-            )
+            logs.debug("Get received unsupported ECacheResult: %s", grpc_get_response.result)  # type: ignore[misc]
             raise error_converter.convert_ecache_result(
                 grpc_get_response.result, grpc_get_response.message, "GET"  # type: ignore[misc]
             )
@@ -120,31 +101,6 @@ class CacheGetResponse:
         return f"CacheGetResponse(value={self._value!r}, status={self._status!r})"
 
 
-class CacheGetMultiResponse:
-    def __init__(self, responses: List[CacheGetResponse]):
-        self._responses = responses
-
-    def status(self) -> List[CacheGetStatus]:
-        return [response.status() for response in self._responses]
-
-    def values(self) -> List[Optional[str]]:
-        """Returns list of values as utf-8 string for each Hit. Each item in list is None if was a Miss."""
-        return [response.value() for response in self._responses]
-
-    def values_as_bytes(self) -> List[Optional[bytes]]:
-        """Returns list of values as bytes for each Hit. Each item in list is None if was a Miss."""
-        return [response.value_as_bytes() for response in self._responses]
-
-    def to_list(self) -> List[CacheGetResponse]:
-        return self._responses
-
-    def __str__(self) -> str:
-        return self.__repr__()
-
-    def __repr__(self) -> str:
-        return f"CacheGetMultiResponse(responses={self._responses!r})"
-
-
 class CacheDeleteResponse:
     def __init__(self) -> None:
         pass
@@ -153,7 +109,7 @@ class CacheDeleteResponse:
         return self.__repr__()
 
     def __repr__(self) -> str:
-        return f"CacheDeleteResponse()"
+        return "CacheDeleteResponse()"
 
 
 class CreateCacheResponse:
@@ -164,7 +120,7 @@ class CreateCacheResponse:
         return self.__repr__()
 
     def __repr__(self) -> str:
-        return f"CreateCacheResponse()"
+        return "CreateCacheResponse()"
 
 
 class DeleteCacheResponse:
@@ -175,7 +131,7 @@ class DeleteCacheResponse:
         return self.__repr__()
 
     def __repr__(self) -> str:
-        return f"DeleteCacheResponse()"
+        return "DeleteCacheResponse()"
 
 
 class CacheInfo:
@@ -277,19 +233,22 @@ class CreateSigningKeyResponse:
         return self._expires_at
 
     @staticmethod
-    def from_grpc_response(grpc_create_signing_key_response: Any, endpoint: str) -> "CreateSigningKeyResponse":  # type: ignore[misc]
+    def from_grpc_response(  # type: ignore[misc]
+        grpc_create_signing_key_response: Any, endpoint: str
+    ) -> "CreateSigningKeyResponse":
         key_id: str = json.loads(grpc_create_signing_key_response.key)["kid"]  # type: ignore[misc]
         key: str = grpc_create_signing_key_response.key  # type: ignore[misc]
-        expires_at: datetime = datetime.fromtimestamp(
-            grpc_create_signing_key_response.expires_at  # type: ignore[misc]
-        )
+        expires_at: datetime = datetime.fromtimestamp(grpc_create_signing_key_response.expires_at)  # type: ignore[misc]
         return CreateSigningKeyResponse(key_id, endpoint, key, expires_at)
 
     def __str__(self) -> str:
         return self.__repr__()
 
     def __repr__(self) -> str:
-        return f"CreateSigningKeyResponse(key_id={self._key_id!r}, endpoint={self._endpoint!r}, key={self._key!r}, expires_at={self._expires_at!r})"
+        return (
+            f"CreateSigningKeyResponse(key_id={self._key_id!r}, endpoint={self._endpoint!r}, "
+            f"key={self._key!r}, expires_at={self._expires_at!r})"
+        )
 
 
 class RevokeSigningKeyResponse:
@@ -300,7 +259,7 @@ class RevokeSigningKeyResponse:
         return self.__repr__()
 
     def __repr__(self) -> str:
-        return f"RevokeSigningKeyResponse()"
+        return "RevokeSigningKeyResponse()"
 
 
 class SigningKey:
@@ -329,9 +288,7 @@ class SigningKey:
     @staticmethod
     def from_grpc_response(grpc_listed_signing_key: Any, endpoint: str) -> "SigningKey":  # type: ignore[misc]
         key_id: str = grpc_listed_signing_key.key_id  # type: ignore[misc]
-        expires_at: datetime = datetime.fromtimestamp(
-            grpc_listed_signing_key.expires_at  # type: ignore[misc]
-        )
+        expires_at: datetime = datetime.fromtimestamp(grpc_listed_signing_key.expires_at)  # type: ignore[misc]
         return SigningKey(key_id, expires_at, endpoint)
 
     def __str__(self) -> str:
@@ -360,13 +317,15 @@ class ListSigningKeysResponse:
         return self._signing_keys
 
     @staticmethod
-    def from_grpc_response(grpc_list_signing_keys_response: Any, endpoint: str) -> "ListSigningKeysResponse":  # type: ignore[misc]
+    def from_grpc_response(  # type: ignore[misc]
+        grpc_list_signing_keys_response: Any, endpoint: str
+    ) -> "ListSigningKeysResponse":
         next_token: Optional[str] = (
             grpc_list_signing_keys_response.next_token  # type: ignore[misc]
             if grpc_list_signing_keys_response.next_token != ""  # type: ignore[misc]
             else None
         )
-        signing_keys: List[SigningKey] = [  # type: ignore[misc]
+        signing_keys: List[SigningKey] = [
             SigningKey.from_grpc_response(signing_key, endpoint)  # type: ignore[misc]
             for signing_key in grpc_list_signing_keys_response.signing_key  # type: ignore[misc]
         ]
